;;; $DOOMDIR/config.el -*- lexical-binding: t; -*-

;; Place your private configuration here! Remember, you do not need to run 'doom
;; sync' after modifying this file!


;; Some functionality uses this to identify you, e.g. GPG configuration, email
;; clients, file templates and snippets.
(setq user-full-name "Anthony Cicchetti"
      user-mail-address "anthony@anthonycicchetti.com")

;; Doom exposes five (optional) variables for controlling fonts in Doom. Here
;; are the three important ones:
;;
;; + `doom-font'
;; + `doom-variable-pitch-font'
;; + `doom-big-font' -- used for `doom-big-font-mode'; use this for
;;   presentations or streaming.
;;
;; They all accept either a font-spec, font string ("Input Mono-12"), or xlfd
;; font string. You generally only need these two:
;; (setq doom-font (font-spec :family "monospace" :size 12 :weight 'semi-light)
;;       doom-variable-pitch-font (font-spec :family "sans" :size 13))
(setq doom-font (font-spec :family "TX-02-BerkeleyAC" :size 14 :weight 'medium)
      doom-unicode-font (font-spec :family "TX-02-BerkeleyAC" :size 14 :weight 'medium))

;; There are two ways to load a theme. Both assume the theme is installed and
;; available. You can either set `doom-theme' or manually load a theme with the
;; `load-theme' function. This is the default:
(setq doom-theme 'doom-henna)

;; Treemacs
(setq treemacs-git-mode 'deferred)

;; If you use `org' and don't want your org files in the default location below,
;; change `org-directory'. It must be set before org loads!
(setq org-directory "~/org-roam/")

(setq org-roam-directory "~/org-roam/")

(setq org-brain-include-file-entries 't)

(setq org-agenda-files '("~/org-roam/agenda/"))

(setq projectile-project-search-path '("~/src" "~/tmp"))

;; This determines the style of line numbers in effect. If set to `nil', line
;; numbers are disabled. For relative line numbers, set this to `relative'.
(setq display-line-numbers-type 'relative)

(auth-source-1password-enable)

;; Here are some additional functions/macros that could help you configure Doom:
;;
;; - `load!' for loading external *.el files relative to this one
;; - `use-package!' for configuring packages
;; - `after!' for running code after a package has loaded
;; - `add-load-path!' for adding directories to the `load-path', relative to
;;   this file. Emacs searches the `load-path' when you load packages with
;;   `require' or `use-package'.
;; - `map!' for binding new keys
;;
;; To get information about any of these functions/macros, move the cursor over
;; the highlighted symbol at press 'K' (non-evil users must press 'C-c c k').
;; This will open documentation for it, including demos of how they are used.
;;
;; You can also try 'gd' (or 'C-c c d') to jump to their definition and see how
;; they are implemented.
(map! :leader
      :desc "Avy - Go To Any Char"
      :n "a" #'avy-goto-char-timer)

(map! :after org
      :desc "Open At Point"
      :n "g[" #'org-open-at-point)

(map! :after evil
      :desc "Evil - Scroll Up"
      :n "C-k" #'evil-scroll-up
      :desc "Evil - Scroll Down"
      :n "C-j" #'evil-scroll-down
      :leader (
               :desc "Evil - Window Right"
               :n "l" #'evil-window-right
               :desc "Evil - Window Left"
               :n "h" #'evil-window-left
               :desc "Evil - Window Down"
               :n "j" #'evil-window-down
               :desc "Evil - Window Up"
               :n "k" #'evil-window-up
               :desc "Evil - Comment"
               :n "g c" #'evilnc-comment-or-uncomment-lines
               :desc "Visualize Undo Tree"
               :n "u" #'undo-tree-visualize
               :desc "Consult Buffer"
               :n "b" #'consult-buffer))

(after! magit
  (evil-define-key 'normal 'global (kbd "<leader>g") 'magit-file-dispatch)
  (evil-define-key 'normal 'global (kbd "<leader>r") 'magit-status))

(use-package! org-transclusion
              :after org
              :init
              (map!
               :map global-map "<f12>" #'org-transclusion-add
               :leader
               :prefix "n"
               :desc "Org Transclusion Mode" "t" #'org-transclusion-mode))

(after! citar
  (setq! citar-bibliography '("~/org-roam/Citations.bib")))

(after! org
  (add-hook 'org-mode-hook #'org-modern-mode)
  (add-hook 'org-agenda-finalize-hook #'org-modern-agenda))
