{ pkgs, ... }:
let
  inherit (pkgs.stdenv.hostPlatform) isDarwin;
in
{
  home = {
    username = "acicchetti";

    homeDirectory = if isDarwin then "/Users/acicchetti" else "/home/acicchetti";

    stateVersion = "24.11";

    sessionVariables = {
      EDITOR = "nvim";
    };
  };

  fonts.fontconfig.enable = true;

  programs = {
    home-manager.enable = true;

    aria2 = {
      enable = true;
    };

    atuin = {
      enable = true;
      enableZshIntegration = true;
      settings = {
        enter_accept = true;
        style = "compact";
        keymap_mode = "vim-insert";
        keymap_cursor = {
          vim_insert = "steady-bar";
          vim_normal = "steady-block";
        };
        sync_address = "https://atuin.acicchetti.dev";
      };
    };

    direnv = {
      enable = true;
      nix-direnv.enable = true;
      enableZshIntegration = true;
    };

    eza = {
      enable = true;
      git = true;
      icons = "auto";
      enableZshIntegration = true;
    };

    gh = {
      enable = true;
      settings = {
        editor = "nvim";
        git_protocol = "ssh";
      };
    };

    htop = {
      enable = true;
    };

    jujutsu = {
      enable = true;
      settings = {
        user = {
          name = "Anthony Cicchetti";
          email = "anthony@anthonycicchetti.com";
        };
        "default-command" = "log";
      };
    };

    nix-index = {
      enable = true;
    };
    nix-index-database = {
      comma.enable = true;
    };

    nnn = {
      enable = true;
    };

    skim = {
      enable = true;
      enableZshIntegration = false;
    };

    tealdeer = {
      enable = true;
    };

    topgrade = {
      enable = true;
      settings = {
        misc = {
          disable = [
            "node"
            "nix"
            "home_manager"
            "gem"
            "ruby_gems"
            "cargo"
            "vim"
            "pipx"
            "pip3"
            "containers"
          ];
          run_in_tmux = true;
          display_time = true;
          skip_notify = true;
        };
        git = {
          max_concurrency = 5;
          pull_predefined = false;
        };
        linux.arch_package_manager = "paru";
      };
    };

    wezterm = {
      enable = true;
      enableZshIntegration = true;
      extraConfig = builtins.readFile ../../wezterm/wezterm.lua;
      # package = wezterm.packages.${pkgs.system}.default;
    };

    yazi = {
      enable = true;
      enableZshIntegration = true;
    };

    zoxide = {
      enable = true;
    };
  };

  imports = [
    ./modules/packages
    ./modules/files.nix
    ./modules/environment.nix
    ./modules/services
  ];
}
