{ pkgs, ... }:
let
  inherit (pkgs.stdenv.hostPlatform) isLinux;
  systemSpecificPackages =
    with pkgs;
    if
      isLinux
    # ncdu (well, all zig packages) don't work on macOS nix right now
    then
      [
        zsh
        racket
        mold
        ncdu
        ghostty
        xorg.libX11
      ]
    else
      [
        keka
        colima
        neovide
        aerospace
      ];
  cy =
    {
      pkgs,
      fetchFromGitHub,
    }:
    let
      ver = "1.3.1";
    in
    pkgs.buildGoModule {
      pname = "cy";
      version = "${ver}";

      src = fetchFromGitHub {
        owner = "cfoust";
        repo = "cy";
        rev = "refs/tags/v${ver}";
        hash = "sha256-i5suNLh1Dy8sWKBasO1rnVRzDetEF77XXRonRk1RzB4=";
      };

      vendorHash = null;

      buildPhase = ''
        runHook preBuild
        export GOCACHE=$PWD/.cache/go-build
        go install ./cmd/cy/
        runHook postBuild
      '';

      installPhase = ''
        runHook preInstall
        install -Dm755 -t $out/bin $GOPATH/bin/cy
        runHook postInstall
      '';
    };
in
{
  imports = [
    ./git.nix
    ./mise.nix
    ./neovim.nix
    ./ssh.nix
    ./starship.nix
    ./zellij.nix
    ./zsh.nix
    # ./cy.nix
  ];
  home.packages =
    with pkgs;
    [
      _1password-cli
      nerd-fonts._0xproto
      bat
      bottom
      cargo-workspaces
      clipboard-jh
      curl
      departure-mono
      docker-client
      dogedns
      erdtree
      erg
      emacs
      fantasque-sans-mono
      fd
      (fenix.latest.withComponents [
        "cargo"
        "clippy"
        "rustfmt"
        "rust-src"
        "rustc"
      ])
      ffmpeg_6
      gawkInteractive
      gnugrep
      gnused
      gnutar
      gping
      gql
      httpstat
      imagemagick
      internetarchive
      jless
      jq
      just
      kondo
      litecli
      magic-wormhole-rs
      maple-mono-NF
      martian-mono
      page
      pandoc
      parallel
      picocrypt
      picocrypt-cli
      python312Packages.pipx
      rage
      ripgrep
      rsync
      rust-analyzer-nightly # part of the fenix distribution/overlay
      scriptisto
      see-cat
      sqlite
      tmux
      vale
      python312Packages.yt-dlp
      zenith
      zstd
    ]
    ++ systemSpecificPackages
    ++ (
      if isLinux then
        [ ]
      else
        [
          (callPackage cy { })
        ]
    );
}
