(module config.plugin
  {autoload {nvim aniseed.nvim
             a aniseed.core
             util config.util
             : packer}})


(defn safe-require-plugin-config [name]
  (let [(ok? val-or-err) (pcall require (.. :config.plugin. name))]
    (when (not ok?)
      (print (.. "config error: " val-or-err)))))

(defn- use [...]
  "Iterates through the arguments as pairs and calls packer's use function for
  each of them. Works around Fennel not liking mixed associative and sequential
  tables as well."
  (let [pkgs [...]]
    (packer.startup
      (fn [use]
        (for [i 1 (a.count pkgs) 2]
          (let [name (. pkgs i)
                opts (. pkgs (+ i 1))]
            (-?> (. opts :mod) (safe-require-plugin-config))
            (use (a.assoc opts 1 name)))))))
  nil)

(use
    ;; Defined further up
    :wbthomason/packer.nvim {}
    :Olical/aniseed {}
    :lewis6991/impatient.nvim {}


    :inkarkat/vim-ReplaceWithRegister {}
    ; :chriskempson/base16-vim {:mod :colorscheme}
    :hardhackerlabs/theme-vim {:mod :colorscheme :as :hardhacker}

    :williamboman/mason.nvim {}
    :williamboman/mason-lspconfig.nvim {}
    :neovim/nvim-lspconfig {:mod :lspconfig :requires [[:williamboman/mason.nvim] [:williamboman/mason-lspconfig.nvim]]}
    :simrat39/inlay-hints.nvim {:mod :inlayhints}

    :ctrlpvim/ctrlp.vim {:mod :ctrlp}

    :radenling/vim-dispatch-neovim {:requires [[:tpope/vim-dispatch]]}

    :moll/vim-bbye {}
    :aymericbeaumet/vim-symlink {}
    :gpanders/editorconfig.nvim {}

    :terryma/vim-expand-region {}

    ;; TODO CONFIGURE
    :nvim-treesitter/nvim-treesitter {:mod :treesitter :event ["BufEnter"] :run ":TSUpdate"}
    "https://git.sr.ht/~p00f/nvim-ts-rainbow" {:requires [[:nvim-treesitter/nvim-treesitter]]}

    :datwaft/bubbly.nvim {:mod :bubbly}

    :tpope/vim-fugitive {:mod :fugitive}
    :tpope/vim-surround {}
    :mhinz/vim-signify {}
    :tpope/vim-commentary {}
    :mbbill/undotree {}
    :folke/which-key.nvim {:mod :which-key}
    :airblade/vim-rooter {}
    :hashivim/vim-terraform {:mod :vim-terraform}
    :imsnif/kdl.vim {}
    :ggandor/leap.nvim {:mod :leap})
