local wezterm = require("wezterm")
local act = wezterm.action

-- Allow working with both the current release and the nightly
local config = {}
if wezterm.config_builder then
	config = wezterm.config_builder()
end

config.font = wezterm.font_with_fallback({
	{ family = "0xProto Nerd Font Mono" },
	{ family = "Maple Mono NF" },
	{ family = "Departure Mono" },
	{ family = "Fantasque Sans Mono" },
	{ family = "Iosevka Custom", weight = "Medium" },
})

config.font_rules = {
	{
		italic = true,
		font = wezterm.font_with_fallback({
			{ family = "Maple Mono NF", italic = true },
			{ family = "Dank Mono", italic = true },
			{ family = "Fantasque Sans Mono", italic = true },
			{ family = "Iosevka Custom", weight = "Light" },
		}),
	},
}

config.font_size = 14.0
-- wayland?
config.enable_wayland = true
-- TERM name
config.term = "xterm-256color"

-- Color Scheme(s)
-- config.color_scheme = "Hopscotch.256"
config.color_schemes = {
	["Corvine"] = {
		background = "#262626",
		foreground = "#c6c6c6",
		-- ansi = {"black", "maroon", "green", "olive", "navy", "purple", "teal", "silver"},
		-- brights = {"grey", "red", "lime", "yellow", "blue", "fuchsia", "aqua", "white"},
		ansi = { "#3a3a3a", "#d7d7d7", "#87af5f", "#d7d7af", "#87afd7", "#afafd7", "#87d7d7", "#c6c6c6" },
		brights = { "#626262", "#ffafaf", "#afd787", "#d7d787", "#87d7ff", "#d7afd7", "#5fd7d7", "#eeeeee" },
	},
	["OceanicNext"] = {
		background = "#1b2b34",
		foreground = "#c0c5ce",
		-- Overrides the cell background color when the current cell is occupied by the
		-- cursor and the cursor style is set to Block
		cursor_bg = "#c0c5ce",
		-- Overrides the text color when the current cell is occupied by the cursor
		cursor_fg = "#1b2b34",
		ansi = { "#1b2b34", "#ec5f67", "#99c794", "#fac863", "#6699cc", "#c594c5", "#5fb3b3", "#c0c5ce" },
		brights = { "#65737e", "#ec5f67", "#99c794", "#fac863", "#6699cc", "#c594c5", "#5fb3b3", "#d8dee9" },
	},
	["Kanagawa"] = {
		-- force_reverse_video_cursor = true,
		foreground = "#dcd7ba",
		background = "#1f1f28",

		cursor_bg = "#c8c093",
		cursor_fg = "#c8c093",
		cursor_border = "#c8c093",

		selection_fg = "#c8c093",
		selection_bg = "#2d4f67",

		scrollbar_thumb = "#16161d",
		split = "#16161d",

		ansi = { "#090618", "#c34043", "#76946a", "#c0a36e", "#7e9cd8", "#957fb8", "#6a9589", "#c8c093" },
		brights = { "#727169", "#e82424", "#98bb6c", "#e6c384", "#7fb4ca", "#938aa9", "#7aa89f", "#dcd7ba" },
		indexed = { [16] = "#ffa066", [17] = "#ff5d62" },
	},
}
config.color_scheme = "Kanagawa"

-- Tab Bar
config.enable_tab_bar = true
config.hide_tab_bar_if_only_one_tab = true

config.front_end = "WebGpu"

-- Wezterm Mux
config.unix_domains = { { name = "unix" } }
config.default_gui_startup_args = { "connect", "unix" }

-- Some keybinds… A lot of keybinds
local copy_mode = nil
if wezterm.gui then
	copy_mode = wezterm.gui.default_key_tables().copy_mode
	table.insert(copy_mode, { key = "k", mods = "CTRL", action = act.CopyMode({ MoveByPage = -0.5 }) })
	table.insert(copy_mode, { key = "j", mods = "CTRL", action = act.CopyMode({ MoveByPage = 0.5 }) })
end
-- config.leader = { key = "a", mods = "CTRL", timeout_milliseconds = 1000 }
-- config.keys = {
-- 	{
-- 		key = "|",
-- 		mods = "LEADER|SHIFT",
-- 		action = act.SplitHorizontal({ domain = "CurrentPaneDomain" }),
-- 	},
-- 	{
-- 		key = "a",
-- 		mods = "LEADER|CTRL",
-- 		action = act.SendKey({ key = "a", mods = "CTRL" }),
-- 	},
-- 	{
-- 		key = "-",
-- 		mods = "LEADER",
-- 		action = act.SplitVertical({ domain = "CurrentPaneDomain" }),
-- 	},
-- 	{
-- 		key = "n",
-- 		mods = "LEADER",
-- 		action = act.ActivateKeyTable({
-- 			name = "manage_panes",
-- 			one_shot = false,
-- 			timeout_milliseconds = 5000,
-- 			until_unknown = true,
-- 		}),
-- 	},

-- 	{
-- 		key = "Escape",
-- 		mods = "LEADER",
-- 		action = act.ActivateCopyMode,
-- 	},
-- 	{ key = "Tab", mods = "LEADER", action = act.QuickSelect },
-- 	{ key = "c", mods = "LEADER", action = act.SpawnTab("CurrentPaneDomain") },
-- }
-- config.key_tables = {
-- 	manage_panes = {
-- 		{ key = "LeftArrow", action = act.AdjustPaneSize({ "Left", 1 }) },
-- 		{ key = "h", action = act.AdjustPaneSize({ "Left", 1 }) },
-- 		{ key = "h", mods = "SHIFT", action = act.ActivatePaneDirection("Left") },

-- 		{ key = "RightArrow", action = act.AdjustPaneSize({ "Right", 1 }) },
-- 		{ key = "l", action = act.AdjustPaneSize({ "Right", 1 }) },
-- 		{ key = "l", mods = "SHIFT", action = act.ActivatePaneDirection("Right") },

-- 		{ key = "UpArrow", action = act.AdjustPaneSize({ "Up", 1 }) },
-- 		{ key = "k", action = act.AdjustPaneSize({ "Up", 1 }) },
-- 		{ key = "k", mods = "SHIFT", action = act.ActivatePaneDirection("Up") },

-- 		{ key = "DownArrow", action = act.AdjustPaneSize({ "Down", 1 }) },
-- 		{ key = "j", action = act.AdjustPaneSize({ "Down", 1 }) },
-- 		{ key = "j", mods = "SHIFT", action = act.ActivatePaneDirection("Down") },

-- 		-- Cancel the mode by pressing escape
-- 		{ key = "Escape", action = "PopKeyTable" },
-- 	},
-- 	copy_mode = copy_mode,
-- }

return config
